@@ -1,9 +1,9 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
-
+#include <R_ext/Lapack.h>
 /* LAPACK */
-extern int dpotf2_(char *, int *, double *, int *, int *); 
+/* extern int dpotf2_(char *, int *, double *, int *, int *); */
 
 double dcholfact(int n, double *A, double *L)
 {
@@ -12,13 +12,13 @@ double dcholfact(int n, double *A, double *L)
 	int indef, i;
 	static double lambda = 1e-3/512/512;
 	memcpy(L, A, sizeof(double)*n*n);
-	dpotf2_("L", &n, L, &n, &indef);
+	F77_CALL(dpotf2)("L", &n, L, &n, &indef);
 	if (indef != 0)
 	{
 		memcpy(L, A, sizeof(double)*n*n);
 		for (i=0;i<n;i++)
 			L[i*n+i] += lambda; 
-		dpotf2_("L", &n, L, &n, &indef);
+		F77_CALL(dpotf2)("L", &n, L, &n, &indef);
 		if (indef != 0)
 		{
 			printf("A is not positive semi-definite\n");
